@@ -72,11 +72,14 @@ class Slide:
 
 
 class BBBDL(InfoExtractor):
-    _VALID_URL = (
-        r'(?P<website>https?://[^/]+)/playback/presentation/2.0/playback.html\?.*?meetingId=(?P<id>[0-9a-f\-]+)'
-    )
+    _VALID_URL = r'''(?x)
+                     (?P<website>https?://[^/]+)/playback/presentation/
+                     (?P<version>[\d\.]+)/
+                     (playback.html\?.*?meetingId=)?
+                     (?P<id>[0-9a-f\-]+)
+                   '''
 
-    def __init__(self, verbose: bool, no_check_certificate: bool, encoder: str, filename: str):
+    def __init__(self, verbose: bool, no_check_certificate: bool, encoder: str, filename: str, audiocodec: str):
         if '_VALID_URL_RE' not in self.__dict__:
             BBBDL._VALID_URL_RE = re.compile(self._VALID_URL)
 
@@ -90,10 +93,12 @@ class BBBDL(InfoExtractor):
         self.verbose = verbose
         self.ydl = youtube_dl.YoutubeDL(ydl_options)
         self.set_downloader(self.ydl)
-        self.ffmpeg = FFMPEG(self.ydl, encoder)
+        self.ffmpeg = FFMPEG(self.ydl, encoder, audiocodec)
 
-    def run(self, dl_url: str, add_webcam: bool, add_annotations: bool, add_cursor, keep_tmp_files: bool, filename: str):
-        m_obj = self._VALID_URL_RE.match(dl_url)
+    def run(
+        self, dl_url: str, add_webcam: bool, add_annotations: bool, add_cursor, keep_tmp_files: bool, filename: str
+    ):
+        m_obj = re.match(self._VALID_URL, dl_url)
 
         video_id = m_obj.group('id')
         video_website = m_obj.group('website')
@@ -208,11 +213,11 @@ class BBBDL(InfoExtractor):
         slideshow_path = self._create_slideshow(slides_infos, video_id, slideshow_w, slideshow_h)
 
         formatted_date = datetime.fromtimestamp(int(start_time) / 1000).strftime('%Y-%m-%dT%H-%M-%S')
-        
+
         if filename is not None:
             result_path = filename
         else:
-            result_path = formatted_date + '_' + title.replace('/','_',title.count('/')) + '.mp4'
+            result_path = formatted_date + '_' + title.replace('/', '_', title.count('/')) + '.mp4'
 
         self.to_screen("Mux Slideshow")
         webcam_w, webcam_h = self._get_webcam_size(slideshow_w, slideshow_h)
@@ -686,6 +691,13 @@ def get_parser():
         default='libx264',
         help='Optional encoder to pass to ffmpeg (default libx264)',
     )
+    parser.add_argument(
+        '--audiocodec',
+        dest='audiocodec',
+        type=str,
+        default='copy',
+        help='Optional audiocodec to pass to ffmpeg (default copy the codec from the original source)',
+    )
 
     parser.add_argument(
         '-f',
@@ -702,7 +714,7 @@ def main(args=None):
     parser = get_parser()
     args = parser.parse_args(args)
 
-    BBBDL(args.verbose, args.no_check_certificate, args.encoder, args.filename).run(
+    BBBDL(args.verbose, args.no_check_certificate, args.encoder, args.filename, args.audiocodec).run(
         args.URL,
         args.add_webcam,
         args.add_annotations,
